@@ -47,6 +47,7 @@ export class WorldModel {
   objects: any;
   tileMap: any;
   tiles: any;
+  messages: any;
   pending_goals: any;
   drop_goals: any;
   stats: {
@@ -79,6 +80,7 @@ export class WorldModel {
     objects = {},
     tileMap = {},
     tiles = [],
+    messages = {},
     pending_goals = [],
     drop_goals = []
   ) {
