@@ -102,6 +102,7 @@ export class MazeView extends DOMWidgetView {
     objects: any = {},
     tileMap: any = {},
     tiles: any = [],
+    messages: any = {},
     pending_goals: any = [],
     drop_goals: any = []
   ) => {
@@ -114,6 +115,7 @@ export class MazeView extends DOMWidgetView {
       objects,
       tileMap,
       tiles,
+      messages,
       pending_goals,
       drop_goals
     );
