@@ -43,11 +43,10 @@ class Maze(DOMWidget):
         # print("calling method: " + method_name)
         cb = datetime.now().strftime('%f')
 
-        if self.model.js_call_counter == 10:
-            _time.sleep(0.2)
-            self.model.js_call_counter = 0
-            
         self.model.js_call_counter +=1
+        if self.model.js_call_counter % 10 == 0:
+            _time.sleep(0.25)
+            
 
         if self.model.has_balance():
             bot = self.bot()
