@@ -50,11 +50,12 @@ class Direction(Enum):
 
 
 class Cell:
-    def __init__(self, x, y, world, background = None):
+    def __init__(self, x, y, world, background = None, msg = None):
         self.x  = x
         self.y = y
         self.world = world
         self.background =  background
+        self.msg = msg
         self.editable = {"pick": True, "drop": True}
     
     
@@ -143,6 +144,11 @@ class Cell:
         self.set_wall(direction, 0)
         if call_js is not None:
             call_js('remove_wall', self.wall_ui_params(direction))
+    
+    def add_msg(self, msg, call_js= None):
+        self.msg = msg
+        if call_js is not None:
+            call_js('add_msg', [self.x, self.y, self.msg ])
  
     
     def has_wall(self, direction):
@@ -185,7 +191,8 @@ class WorldModel():
         self.options = {'MAX_INSTRUCTION_COUNT': 1000}
         self.instruction_count = 0
         self.options.update(options)
-        self.js_call_counter = 0
+        self.js_call_counter = 1
+        self.messages = {}
 
         if path is not None:
             data = self.load_json(path)
@@ -244,7 +251,12 @@ class WorldModel():
         cell.background = background
         self.tiles[x - 1][y -1] = background
 
-    
+    def add_msg(self, x, y, msg, call_js = None):
+        pos = "{},{}".format(x,y)
+        self.messages[pos] = msg
+        cell = self.cells[x - 1][y - 1]
+        cell.add_msg(msg, call_js)
+
     def add_description(self, desc):
         if isinstance(desc, list):
             self.description = '\n'.join(desc)
@@ -350,6 +362,7 @@ class WorldModel():
             self.objects,
             self.tilemap,
             self.tiles,
+            self.messages,
             [x.msg() for x in self.goals],
             [{"obj_name": x.obj_name, "x": x.x, "y": x.y, "val": x.val} for x in self.drop_goals()]
         ])
