@@ -275,7 +275,24 @@ class Robot():
                 return sum(fobjs.values())
         else: 
             return 0
-        
+    
+    def read_message(self):
+        """Check and returns the message in the current cell.
+
+        Returns
+        -------
+        str
+            Returns the message if there is a message in the current cell.
+            None otherwise
+
+        Examples
+        --------
+        >>> bot.read_message()
+        "Hi There"
+        """
+        cell = self.cell()
+        return cell.msg 
+
 
     def object_here(self):
         """Check and return the name of the object in the current cell.
@@ -299,6 +316,7 @@ class Robot():
             obj_name = next(iter(obj))
             if collection is not None:
                 cobj = collection.get(obj_name, None)
+
                 if cobj is not None and cobj == obj[obj_name]:
                     return None
             return obj_name
@@ -381,9 +399,10 @@ class Robot():
                 else:
                     del collection[o_name]
                 self.collections[ck] = collection
+                k = "{},{}".format(self.x,self.y)
+                obj_here = self.world_model.objects.get(k, {}).get(o_name, 0) + 1
+                self.world_model.add_object(self.x, self.y, o_name, obj_here, self.world.js_call)
 
-                self.world_model.add_object(self.x, self.y, o_name, 1, self.world.js_call)
-            
 
     #change very ref of this method and use object here
     def on_object(self, obj_type=None):
@@ -407,7 +426,7 @@ class Robot():
         --------
         >>> bot.take()
         """
-        if self.max_capacity is not None and self.max_capacity < len(self.last_picked):
+        if self.max_capacity is not None and self.max_capacity <= len(self.last_picked):
             raise RuntimeError(f"Can't Carry more than {self.max_capacity} items")
 
         self.world_model.incr_instruction()
@@ -428,6 +447,7 @@ class Robot():
                     self.last_picked.append([k, ck])
                     self.collections[ck] = collection
                     if val == picked:
+                        del self.world_model.objects[ck]
                         self.world.js_call('remove_object', [self.x,self.y])
                     if val > picked:
                         self.world.js_call('update_object', [self.x, self.y, val - picked])
